@@ -41,6 +41,14 @@ def click(x, y, button=1, check=True):
     doDelay(config.actionDelay)
 
 
+def point(x, y, check=True):
+    if check:
+        checkCoordinates(x, y)
+    logger.log("Pointing mouse cursor at (%s,%s)" % (x, y))
+    registry.generateMouseEvent(x, y, 'abs')
+    doDelay(config.actionDelay)
+
+
 def doubleClick(x, y, button=1, check=True):
     """
     Synthesize a mouse button double-click at (x,y)
@@ -190,6 +198,9 @@ keyNameAliases = {
     'ins': 'Insert',
     'pageup': 'Page_Up',
     'pagedown': 'Page_Down',
+    'win': 'Super_L',
+    'meta': 'Super_L',
+    'super': 'Super_L',
     ' ': 'space',
     '\t': 'Tab',
     '\n': 'Return'
@@ -278,3 +289,15 @@ def keyCombo(comboString):
         code = keyNameToKeyCode(modifier)
         registry.generateKeyboardEvent(code, None, KEY_RELEASE)
     doDelay()
+
+
+def holdKey(keyName):
+    code = keyNameToKeyCode(keyName)
+    registry.generateKeyboardEvent(code, None, KEY_PRESS)
+    doDelay()
+
+
+def releaseKey(keyName):
+    code = keyNameToKeyCode(keyName)
+    registry.generateKeyboardEvent(code, None, KEY_RELEASE)
+    doDelay()
