@@ -12,6 +12,7 @@ from types import LambdaType
 import gi
 from gi.repository import GLib
 import os
+import sys
 
 try:
     import pyatspi
@@ -169,7 +170,7 @@ class Action(object):
         """
         Performs the given tree.Action, with appropriate delays and logging.
         """
-        logger.log("%s on %s" % (self.name, self.node.getLogString()))
+        logger.log(str("%s on %s") % (str(self.name), self.node.getLogString()))
         if not self.node.sensitive:
             if config.ensureSensitivity:
                 raise NotSensitiveError(self)
@@ -257,7 +258,7 @@ class Node(object):
 
         invalidChildren = childCount - len(children)
         if invalidChildren and config.debugSearching:
-            logger.log("Skipped %s invalid children of %s" %
+            logger.log(str("Skipped %s invalid children of %s") %
                        (invalidChildren, str(self)))
         try:
             ht = self.queryHypertext()
@@ -328,7 +329,7 @@ class Node(object):
 
     @combovalue.setter
     def combovalue(self, value):
-        logger.log("Setting combobox %s to '%s'" % (self.getLogString(), value))
+        logger.log(str("Setting combobox %s to '%s'") % (self.getLogString(), str(value)))
         self.childNamed(childName=value).doActionNamed('click')
         doDelay()
 
@@ -376,7 +377,7 @@ class Node(object):
                     txt = text[:134] + " [...]"
                 else:
                     txt = text
-                logger.log(msg % (self.getLogString(), "'%s'" % txt))
+                logger.log(str(msg) % (self.getLogString(), str("'%s'") % str(txt)))
             self.queryEditableText().setTextContents(text)
         except NotImplementedError:
             raise AttributeError("can't set attribute")
@@ -456,12 +457,12 @@ class Node(object):
             - 2 is middle,
             - 3 is right.
         """
-        logger.log("Clicking on %s" % self.getLogString())
+        logger.log(str("Clicking on %s") % self.getLogString())
         clickX = self.position[0] + self.size[0] / 2
         clickY = self.position[1] + self.size[1] / 2
         if config.debugSearching:
-            logger.log("raw click on %s %s at (%s,%s)" %
-                       (self.name, self.getLogString(), str(clickX), str(clickY)))
+            logger.log(str("raw click on %s %s at (%s,%s)") %
+                       (str(self.name), self.getLogString(), str(clickX), str(clickY)))
         rawinput.click(clickX, clickY, button)
 
     def doubleClick(self, button=1):
@@ -471,8 +472,8 @@ class Node(object):
         clickX = self.position[0] + self.size[0] / 2
         clickY = self.position[1] + self.size[1] / 2
         if config.debugSearching:
-            logger.log("raw click on %s %s at (%s,%s)" %
-                       (self.name, self.getLogString(), str(clickX), str(clickY)))
+            logger.log(str("raw click on %s %s at (%s,%s)") %
+                       (str(self.name), self.getLogString(), str(clickX), str(clickY)))
         rawinput.doubleClick(clickX, clickY, button)
 
     def point(self, mouseDelay=None):
@@ -481,8 +482,8 @@ class Node(object):
         """
         pointX = self.position[0] + self.size[0] / 2
         pointY = self.position[1] + self.size[1] / 2
-        logger.log("Pointing on %s %s at (%s,%s)" %
-                   (self.name, self.getLogString(), str(pointX), str(pointY)))
+        logger.log(str("Pointing on %s %s at (%s,%s)") %
+                   (str(self.name), self.getLogString(), str(pointX), str(pointY)))
         rawinput.registry.generateMouseEvent(pointX, pointY, 'abs')
         if mouseDelay:
             doDelay(mouseDelay)
@@ -708,7 +709,7 @@ class Node(object):
         """
         Type the given text into the node, with appropriate delays and logging.
         """
-        logger.log("Typing text into %s: '%s'" % (self.getLogString(), string))
+        logger.log(str("Typing text into %s: '%s'") % (self.getLogString(), str(string)))
 
         if self.focusable:
             if not self.focused:
@@ -726,8 +727,8 @@ class Node(object):
 
     def keyCombo(self, comboString):
         if config.debugSearching:
-            logger.log("Pressing keys '%s' into %s" %
-                       (comboString, self.getLogString()))
+            logger.log(str("Pressing keys '%s' into %s") %
+                       (str(comboString), self.getLogString()))
         if self.focusable:
             if not self.focused:
                 try:
@@ -855,12 +856,18 @@ class Node(object):
         else:
             return False
 
-    def _fastFindChild(self, pred, recursive=True):
+    def _fastFindChild(self, pred, recursive=True, showingOnly=None):
         """
         Searches for an Accessible using methods from pyatspi.utils
         """
         if isinstance(pred, predicate.Predicate):
             pred = pred.satisfiedByNode
+        if showingOnly is None:
+            showingOnly = config.searchShowingOnly
+        if showingOnly:
+            orig_pred = pred
+            pred = lambda n: orig_pred(n) and \
+                             n.getState().contains(pyatspi.STATE_SHOWING)
         if not recursive:
             cIter = iter(self)
             while True:
@@ -873,7 +880,7 @@ class Node(object):
         else:
             return pyatspi.utils.findDescendant(self, pred)
 
-    def findChild(self, pred, recursive=True, debugName=None, retry=True, requireResult=True):
+    def findChild(self, pred, recursive=True, debugName=None, retry=True, requireResult=True, showingOnly=None):
         """
         Search for a node satisyfing the predicate, returning a Node.
 
@@ -896,16 +903,24 @@ class Node(object):
                 noun = "child"
             if debugName is None:
                 debugName = pred.describeSearchResult()
-            return "%s of %s: %s" % (noun, parent.getLogString(), debugName)
+            return str("%s of %s: %s") % (str(noun), parent.getLogString(), str(debugName))
+
+        compare_func = None
+        if isinstance(pred, LambdaType):
+            compare_func = pred
+            if debugName is None:
+                debugName = "child satisyfing a custom lambda function"
+        else:
+            assert isinstance(pred, predicate.Predicate)
+            compare_func = pred.satisfiedByNode
 
-        assert isinstance(pred, predicate.Predicate)
         numAttempts = 0
         while numAttempts < config.searchCutoffCount:
             if numAttempts >= config.searchWarningThreshold or config.debugSearching:
-                logger.log("searching for %s (attempt %i)" %
+                logger.log(str("searching for %s (attempt %i)") %
                            (describeSearch(self, pred, recursive, debugName), numAttempts))
 
-            result = self._fastFindChild(pred.satisfiedByNode, recursive)
+            result = self._fastFindChild(compare_func, recursive, showingOnly=showingOnly)
             if result:
                 assert isinstance(result, Node)
                 if debugName:
@@ -924,7 +939,7 @@ class Node(object):
             raise SearchError(describeSearch(self, pred, recursive, debugName))
 
     # The canonical "search for multiple" method:
-    def findChildren(self, pred, recursive=True, isLambda=False):
+    def findChildren(self, pred, recursive=True, isLambda=False, showingOnly=None):
         """
         Find all children/descendents satisfying the predicate.
         You can also use lambdas in place of pred that will enable search also against
@@ -938,6 +953,12 @@ class Node(object):
         else:
             assert isinstance(pred, predicate.Predicate)
             compare_func = pred.satisfiedByNode
+        if showingOnly is None:
+            showingOnly = config.searchShowingOnly
+        if showingOnly:
+            orig_compare_func = compare_func
+            compare_func = lambda n: orig_compare_func(n) and \
+                                     n.getState().contains(pyatspi.STATE_SHOWING)
 
         results = []
         numAttempts = 0
@@ -960,7 +981,7 @@ class Node(object):
         return results
 
     # The canonical "search above this node" method:
-    def findAncestor(self, pred):
+    def findAncestor(self, pred, showingOnly=None):
         """
         Search up the ancestry of this node, returning the first Node
         satisfying the predicate, or None.
@@ -976,7 +997,7 @@ class Node(object):
         return None
 
     # Various wrapper/helper search methods:
-    def child(self, name='', roleName='', description='', label='', recursive=True, retry=True, debugName=None):
+    def child(self, name='', roleName='', description='', label='', recursive=True, retry=True, debugName=None, showingOnly=None):
         """
         Finds a child satisying the given criteria.
 
@@ -985,9 +1006,9 @@ class Node(object):
         also logs the search.
         """
         return self.findChild(predicate.GenericPredicate(name=name, roleName=roleName, description=description,
-                              label=label), recursive=recursive, retry=retry, debugName=debugName)
+                              label=label), recursive=recursive, retry=retry, debugName=debugName, showingOnly=showingOnly)
 
-    def isChild(self, name='', roleName='', description='', label='', recursive=True, retry=False, debugName=None):
+    def isChild(self, name='', roleName='', description='', label='', recursive=True, retry=False, debugName=None, showingOnly=None):
         """
         Determines whether a child satisying the given criteria exists.
 
@@ -1002,12 +1023,12 @@ class Node(object):
             self.findChild(
                 predicate.GenericPredicate(
                     name=name, roleName=roleName, description=description, label=label),
-                recursive=recursive, retry=retry, debugName=debugName)
+                recursive=recursive, retry=retry, debugName=debugName, showingOnly=showingOnly)
         except SearchError:
             found = False
         return found
 
-    def menu(self, menuName, recursive=True):
+    def menu(self, menuName, recursive=True, showingOnly=None):
         """
         Search below this node for a menu with the given name.
 
@@ -1015,9 +1036,9 @@ class Node(object):
         if no such child is found, and will eventually raise an exception. It
         also logs the search.
         """
-        return self.findChild(predicate.IsAMenuNamed(menuName=menuName), recursive)
+        return self.findChild(predicate.IsAMenuNamed(menuName=menuName), recursive, showingOnly=showingOnly)
 
-    def menuItem(self, menuItemName, recursive=True):
+    def menuItem(self, menuItemName, recursive=True, showingOnly=None):
         """
         Search below this node for a menu item with the given name.
 
@@ -1025,9 +1046,9 @@ class Node(object):
         if no such child is found, and will eventually raise an exception. It
         also logs the search.
         """
-        return self.findChild(predicate.IsAMenuItemNamed(menuItemName=menuItemName), recursive)
+        return self.findChild(predicate.IsAMenuItemNamed(menuItemName=menuItemName), recursive, showingOnly=showingOnly)
 
-    def textentry(self, textEntryName, recursive=True):
+    def textentry(self, textEntryName, recursive=True, showingOnly=None):
         """
         Search below this node for a text entry with the given name.
 
@@ -1035,9 +1056,9 @@ class Node(object):
         if no such child is found, and will eventually raise an exception. It
         also logs the search.
         """
-        return self.findChild(predicate.IsATextEntryNamed(textEntryName=textEntryName), recursive)
+        return self.findChild(predicate.IsATextEntryNamed(textEntryName=textEntryName), recursive, showingOnly=showingOnly)
 
-    def button(self, buttonName, recursive=True):
+    def button(self, buttonName, recursive=True, showingOnly=None):
         """
         Search below this node for a button with the given name.
 
@@ -1045,9 +1066,9 @@ class Node(object):
         if no such child is found, and will eventually raise an exception. It
         also logs the search.
         """
-        return self.findChild(predicate.IsAButtonNamed(buttonName=buttonName), recursive)
+        return self.findChild(predicate.IsAButtonNamed(buttonName=buttonName), recursive, showingOnly=showingOnly)
 
-    def childLabelled(self, labelText, recursive=True):
+    def childLabelled(self, labelText, recursive=True, showingOnly=None):
         """
         Search below this node for a child labelled with the given text.
 
@@ -1055,9 +1076,9 @@ class Node(object):
         if no such child is found, and will eventually raise an exception. It
         also logs the search.
         """
-        return self.findChild(predicate.IsLabelledAs(labelText), recursive)
+        return self.findChild(predicate.IsLabelledAs(labelText), recursive, showingOnly=showingOnly)
 
-    def childNamed(self, childName, recursive=True):
+    def childNamed(self, childName, recursive=True, showingOnly=None):
         """
         Search below this node for a child with the given name.
 
@@ -1065,9 +1086,9 @@ class Node(object):
         if no such child is found, and will eventually raise an exception. It
         also logs the search.
         """
-        return self.findChild(predicate.IsNamed(childName), recursive)
+        return self.findChild(predicate.IsNamed(childName), recursive, showingOnly=showingOnly)
 
-    def tab(self, tabName, recursive=True):
+    def tab(self, tabName, recursive=True, showingOnly=None):
         """
         Search below this node for a tab with the given name.
 
@@ -1075,7 +1096,7 @@ class Node(object):
         if no such child is found, and will eventually raise an exception. It
         also logs the search.
         """
-        return self.findChild(predicate.IsATabNamed(tabName=tabName), recursive)
+        return self.findChild(predicate.IsATabNamed(tabName=tabName), recursive, showingOnly=showingOnly)
 
     def getUserVisibleStrings(self):
         """
@@ -1138,7 +1159,7 @@ class Root (Node):
         """
         Get all applications.
         """
-        return root.findChildren(predicate.GenericPredicate(roleName="application"), recursive=False)
+        return root.findChildren(predicate.GenericPredicate(roleName="application"), recursive=False, showingOnly=False)
 
     def application(self, appName, retry=True):
         """
@@ -1149,11 +1170,11 @@ class Root (Node):
         if no such child is found, and will eventually raise an exception. It
         also logs the search.
         """
-        return root.findChild(predicate.IsAnApplicationNamed(appName), recursive=False, retry=retry)
+        return root.findChild(predicate.IsAnApplicationNamed(appName), recursive=False, retry=retry, showingOnly=False)
 
 
 class Application (Node):
-    def dialog(self, dialogName, recursive=False):
+    def dialog(self, dialogName, recursive=False, showingOnly=None):
         """
         Search below this node for a dialog with the given name,
         returning a Window instance.
@@ -1164,9 +1185,9 @@ class Application (Node):
 
         FIXME: should this method activate the dialog?
         """
-        return self.findChild(predicate.IsADialogNamed(dialogName=dialogName), recursive)
+        return self.findChild(predicate.IsADialogNamed(dialogName=dialogName), recursive, showingOnly=showingOnly)
 
-    def window(self, windowName, recursive=False):
+    def window(self, windowName, recursive=False, showingOnly=None):
         """
         Search below this node for a window with the given name,
         returning a Window instance.
@@ -1179,13 +1200,13 @@ class Application (Node):
         The window will be automatically activated (raised and focused
         by the window manager) if wnck bindings are available.
         """
-        result = self.findChild(predicate.IsAWindowNamed(windowName=windowName), recursive)
+        result = self.findChild(predicate.IsAWindowNamed(windowName=windowName), recursive, showingOnly=showingOnly)
         # FIXME: activate the WnckWindow ?
         # if gotWnck:
         #       result.activate()
         return result
 
-    def getWnckApplication(self):  # pragma: no cover
+    def getWnckApplication(self, showingOnly=None):  # pragma: no cover
         """
         Get the wnck.Application instance for this application, or None
 
@@ -1196,7 +1217,7 @@ class Application (Node):
 
         FIXME: untested
         """
-        window = self.child(roleName='frame')
+        window = self.child(roleName='frame', showingOnly=showingOnly)
         if window:
             wnckWindow = window.getWnckWindow()
             return wnckWindow.get_application()
@@ -1249,7 +1270,7 @@ class Wizard (Window):
         Node.__init__(self, node)
         if debugName:
             self.debugName = debugName
-        logger.log("%s is on '%s' page" % (self, self.getPageTitle()))
+        logger.log(str("%s is on '%s' page") % (self, str(self.getPageTitle())))
 
     def currentPage(self):
         """
@@ -1287,7 +1308,7 @@ class Wizard (Window):
         fwd.click()
 
         # Log the new wizard page; it's helpful when debugging scripts
-        logger.log("%s is now on '%s' page" % (self, self.getPageTitle()))
+        logger.log(str("%s is now on '%s' page") % (self, str(self.getPageTitle())))
         # FIXME disabled for now (can't get valid page titles)
 
     def clickApply(self):
@@ -1320,18 +1341,20 @@ if not children:  # pragma: no cover
         "Warning: AT-SPI's desktop is visible but it has no children. Are you running any AT-SPI-aware applications?")
 del children
 
-# sniff also imports from tree and we don't want to run this code from
-# sniff itself
+# sniff also imports from tree and we don't want to run this code from sniff itself
 if not os.path.exists('/tmp/sniff_running.lock'):
     if not os.path.exists('/tmp/sniff_refresh.lock'):  # may have already been locked by dogtail.procedural
-        # tell sniff not to use auto-refresh while script using this module is
-        # running
-        sniff_lock = Lock(lockname='sniff_refresh.lock', randomize=False)
+        # 'tell' newly opened sniff not to use auto-refresh while script using this module is running
+        sniff_lock = Lock(lockname='sniff_refresh.lock', randomize=False, unlockOnExit=True)
         try:
             sniff_lock.lock()
         except OSError:  # pragma: no cover
-            pass  # lock was already present from other script instance or leftover from killed instance
-        # lock should unlock automatically on script exit.
+            pass
+elif 'sniff' not in sys.argv[0]:
+    print("Dogtail: Warning: Running sniff has been detected.")
+    print("Please make sure sniff has the 'Auto Refresh' disabled.")
+    print("NOTE: Running scripts with sniff present is not recommended.")
+
 
 # Convenient place to set some debug variables:
 # config.debugSearching = True
