@@ -8,6 +8,8 @@ import dogtail.rawinput
 from gtkdemotest import GtkDemoTest, trap_stdout
 import pyatspi
 import time
+import unittest
+import os
 
 """
 Unit tests for the dogtail.Node class
@@ -361,7 +363,7 @@ class TestNode(GtkDemoTest):
         Node.visible reflects a node property if is should be render or not
         """
         self.assertTrue(self.app.child(roleName='frame').visible)
-        self.assertFalse(self.app.child('column', roleName='table column header').visible)
+        self.assertFalse(self.app.child(roleName='table column header').visible)
 
     def test_set_visible(self):
         """
@@ -657,6 +659,15 @@ class TestSearching(GtkDemoTest):
         counter = get_table_cells_recursively(self.app)
         self.assertEqual(len(tableCells), counter)
 
+    def test_findChild_lambda(self):
+        """
+        Ensure that the lambda usage works as expected with Node.findChild
+        """
+        try:
+            self.app.findChild(lambda x: x.roleName == 'page tab list')
+        except dogtail.tree.SearchError:
+            self.fail("Got a SearchError trying to find the page tab list")
+
     def test_findChildren2(self):
         """
         Ensure that there are two tabs in the second page tab list.
@@ -666,7 +677,7 @@ class TestSearching(GtkDemoTest):
         pred = dogtail.predicate.GenericPredicate(roleName='page tab')
         # only one page tab list present since gtk3-demo 3.14
         pageTabs = pageTabList[0].findChildren(pred)
-        self.assertEqual(len(pageTabs), 4)
+        self.assertEqual(len(pageTabs), 5)
 
     def test_findChildren2_lambda(self):
         """
@@ -674,7 +685,7 @@ class TestSearching(GtkDemoTest):
         """
         pageTabList = self.app.findChildren(lambda x: x.roleName == 'page tab list')
         pageTabs = pageTabList[0].findChildren(lambda x: x.roleName == 'page tab')
-        self.assertEqual(len(pageTabs), 4)
+        self.assertEqual(len(pageTabs), 5)
 
     def test_findChildren_lambdas(self):
         """
@@ -702,7 +713,7 @@ class TestSearching(GtkDemoTest):
         self.assertTrue(texts2[1].showing)
 
     def test_findAncestor(self):
-        pred = dogtail.predicate.GenericPredicate(roleName='tree table')
+        pred = dogtail.predicate.GenericPredicate(roleName='table cell')
         child = self.app.child("Builder")
         parent = child.findAncestor(pred)
         self.assertIn(child, parent.children)
@@ -848,6 +859,53 @@ class TestSearching(GtkDemoTest):
         self.assertIsNotNone(wnd.button("Message Dialog"))
 
 
+# A painful point of collision between strings in python2 and python3!
+@unittest.skipIf(os.system('ls /usr/bin/gedit') != 0, "Skipping, need gedit")
+class TestUnicodeNames(unittest.TestCase):
+
+    def setUp(self):
+        import dogtail.config
+        dogtail.config.config.logDebugToStdOut = True
+        dogtail.config.config.logDebugToFile = True
+        dogtail.config.config.logDebugToStdOut = True
+        dogtail.config.config.debugSearching = True
+        dogtail.config.config.searchCutoffCount = 3
+        import dogtail.utils
+        self.pid = dogtail.utils.run('gedit')
+        self.app = dogtail.tree.root.application('gedit')
+
+    def test_unicode_char_in_name(self):
+        self.app.child('Open', roleName='toggle button').click()
+        unicode_button = None
+        unicode_button = self.app.child(name=u'Other Documents…', roleName='push button')
+        assert unicode_button is not None
+
+    def test_unicode_char_in_name_click(self):
+        self.app.child('Open', roleName='toggle button').click()
+        unicode_button = self.app.child(name=u'Other Documents…', roleName='push button')
+        unicode_button.click()
+        dialog = None
+        try:
+            dialog = self.app.child(name=u'Open', roleName='file chooser')
+        except dogtail.tree.SearchError:
+            self.fail()
+        assert dialog is not None
+
+    def test_unicode_logging_nocrash(self):
+        try:
+            self.app.child(name='…Other stuff…', roleName='push button')
+            self.fail()
+        except dogtail.tree.SearchError:
+            pass
+
+    def tearDown(self):
+        import signal
+        os.kill(self.pid, signal.SIGKILL)
+        os.system('killall gedit > /dev/null 2>&1')
+        # Sleep just enough to let the app actually die.
+        # AT-SPI doesn't like being hammered too fast.
+        time.sleep(0.5)
+
 class TestDump(GtkDemoTest):
 
     def test_dump_to_stdout(self):
@@ -862,11 +920,11 @@ class TestDump(GtkDemoTest):
   [scroll bar | ]""")
 
     def test_dump_with_actions(self):
-        child = self.app.child('Builder')
+        child = self.app.child('Builder', roleName='table cell')
         output = trap_stdout(child.dump)
         self.assertEqual(
             output,
             """[table cell | Builder]
+ [action | activate |  ]
  [action | edit |  ]
- [action | expand or contract |  ]
- [action | activate |  ]""")
+ [action | expand or contract |  ]""")
