@@ -87,7 +87,7 @@ class TestRun(unittest.TestCase):
         with self.assertRaises(OSError):
             self.pid = dogtail.utils.run('gtk3-virtual-nonexisting-demo')
 
-    def test_run_dump(self):
+    def test_run_dumb(self):
         self.pid = dogtail.utils.run('gtk3-demo', dumb=True)
         dogtail.tree.root.application('gtk3-demo')
 
@@ -124,9 +124,13 @@ class TestA11Y(unittest.TestCase):
 
 
 class TestLock(unittest.TestCase):
+
+    def tearDown(self):
+        os.system("rm -rf /tmp/dogtail-test.lock*")
+
     def test_set_unrandomized_lock(self):
-        test_lock = dogtail.utils.Lock(lockname='test.lock', randomize=False)
-        self.assertEqual(test_lock.lockdir, "/tmp/test.lock")
+        test_lock = dogtail.utils.Lock(lockname='dogtail-test.lock', randomize=False)
+        self.assertEqual(test_lock.lockdir, "/tmp/dogtail-test.lock")
         self.assertFalse(os.path.isdir(test_lock.lockdir))
         test_lock.lock()
         self.assertTrue(os.path.isdir(test_lock.lockdir))
@@ -134,28 +138,21 @@ class TestLock(unittest.TestCase):
         self.assertFalse(os.path.isdir(test_lock.lockdir))
 
     def test_double_lock(self):
-        test_lock = dogtail.utils.Lock(lockname='test.lock', randomize=False)
+        test_lock = dogtail.utils.Lock(lockname='dogtail-test.lock', randomize=False, unlockOnExit=True)
         test_lock.lock()
         with self.assertRaises(OSError):
             test_lock.lock()
 
     def test_double_unlock(self):
-        test_lock = dogtail.utils.Lock(lockname='test.lock', randomize=False)
+        test_lock = dogtail.utils.Lock(lockname='dogtail-test.lock', randomize=False)
         test_lock.lock()
         test_lock.unlock()
         with self.assertRaises(OSError):
             test_lock.unlock()
 
-    def test_lock_on_del(self):
-        test_lock = dogtail.utils.Lock(lockname='test.lock', randomize=False)
-        test_lock.lock()
-        test_dir = test_lock.lockdir
-        del test_lock
-        self.assertFalse(os.path.isdir(test_dir))
-
     def test_randomize(self):
-        test_lock = dogtail.utils.Lock(lockname='test.lock', randomize=True)
-        self.assertIn("/tmp/test.lock", test_lock.lockdir)
+        test_lock = dogtail.utils.Lock(lockname='dogtail-test.lock', randomize=True)
+        self.assertIn("/tmp/dogtail-test.lock", test_lock.lockdir)
         self.assertFalse(os.path.isdir(test_lock.lockdir))
         test_lock.lock()
         self.assertTrue(os.path.isdir(test_lock.lockdir))
